==> winnie-0.1.46.tgz: package/templates/crud.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var Button = require('kenga-buttons/button');
var Anchors = require('kenga-containers/anchors-pane');
var Toolbar = require('kenga-containers/tool-bar');
var DataGrid = require('kenga-grid/grid');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var Button__default = /*#__PURE__*/_interopDefaultLegacy(Button);
var Anchors__default = /*#__PURE__*/_interopDefaultLegacy(Anchors);
var Toolbar__default = /*#__PURE__*/_interopDefaultLegacy(Toolbar);
var DataGrid__default = /*#__PURE__*/_interopDefaultLegacy(DataGrid);

var KengaWidgets = function KengaWidgets() {
  _classCallCheck__default['default'](this, KengaWidgets);

  var anchorsPane = new Anchors__default['default']();
  {
    anchorsPane.element.style.width = '500px';
    anchorsPane.element.style.height = '500px';
  }
  this.anchorsPane = anchorsPane;
  var button = new Button__default['default']();
  {
    button.text = 'Close';
    button.element.style.left = '400px';
    button.element.style.width = '91px';
    button.element.style.top = '460px';
    button.element.style.height = '32px';
  }
  this.button = button;
  var button1 = new Button__default['default']();
  {
    button1.text = 'Save';
    button1.element.style.left = '290px';
    button1.element.style.width = '91px';
    button1.element.style.top = '460px';
    button1.element.style.height = '32px';
  }
  this.button1 = button1;
  var boxPane = new Toolbar__default['default']();
  {
    boxPane.element.style.left = '0px';
    boxPane.element.style.right = '0px';
    boxPane.element.style.top = '0px';
    boxPane.element.style.height = '38px';
  }
  this.boxPane = boxPane;
  var dataGrid = new DataGrid__default['default']();
  {
    dataGrid.evenRowsColor = '#f1f1f1';
    dataGrid.element.style.left = '63px';
    dataGrid.element.style.width = '374px';
    dataGrid.element.style.top = '127px';
    dataGrid.element.style.height = '224px';
  }
  this.dataGrid = dataGrid;
  anchorsPane.add(button);
  anchorsPane.add(button1);
  anchorsPane.add(boxPane);
  anchorsPane.add(dataGrid);
};

module.exports = KengaWidgets;

==> winnie-0.1.55.tgz: package/templates/crud.js <==
'use strict';

var _classCallCheck = require('@babel/runtime/helpers/classCallCheck');
var Button = require('kenga-buttons/button');
var Anchors = require('kenga-containers/anchors-pane');
var Toolbar = require('kenga-containers/tool-bar');
var DataGrid = require('kenga-grid/grid');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _classCallCheck__default = /*#__PURE__*/_interopDefaultLegacy(_classCallCheck);
var Button__default = /*#__PURE__*/_interopDefaultLegacy(Button);
var Anchors__default = /*#__PURE__*/_interopDefaultLegacy(Anchors);
var Toolbar__default = /*#__PURE__*/_interopDefaultLegacy(Toolbar);
var DataGrid__default = /*#__PURE__*/_interopDefaultLegacy(DataGrid);

var KengaWidgets = function KengaWidgets() {
  _classCallCheck__default["default"](this, KengaWidgets);

  var anchorsPane = new Anchors__default["default"]();
  {
    anchorsPane.element.style.width = '500px';
    anchorsPane.element.style.height = '500px';
  }
  this.anchorsPane = anchorsPane;
  var button = new Button__default["default"]();
  {
    button.text = 'Close';
    button.element.style.left = '400px';
    button.element.style.width = '91px';
    button.element.style.top = '460px';
    button.element.style.height = '32px';
  }
  this.button = button;
  var button1 = new Button__default["default"]();
  {
    button1.text = 'Save';
    button1.element.style.left = '290px';
    button1.element.style.width = '91px';
    button1.element.style.top = '460px';
    button1.element.style.height = '32px';
  }
  this.button1 = button1;
  var boxPane = new Toolbar__default["default"]();
  {
    boxPane.element.style.left = '0px';
    boxPane.element.style.right = '0px';
    boxPane.element.style.top = '0px';
    boxPane.element.style.height = '38px';
  }
  this.boxPane = boxPane;
  var dataGrid = new DataGrid__default["default"]();
  {
    dataGrid.evenRowsColor = '#f1f1f1';
    dataGrid.element.style.left = '63px';
    dataGrid.element.style.width = '374px';
    dataGrid.element.style.top = '127px';
    dataGrid.element.style.height = '224px';
  }
  this.dataGrid = dataGrid;
  anchorsPane.add(button);
  anchorsPane.add(button1);
  anchorsPane.add(boxPane);
  anchorsPane.add(dataGrid);
};

module.exports = KengaWidgets;
